<?php
/*
Plugin Name: DrawBlog
Plugin URI: http://drawblog.com/
Description: A WordPress plugin that allows commenters to draw a picture.
Version: 0.77
Author: Randy Tayler
Author URI: http://randytayler.com
License: GPL

*/
global $drawblog_db_version;
global $drawblog_form_complete;
$drawblog_db_version = "0.63";
/* Runs when plugin is activated */
register_activation_hook(__FILE__,'drawblog_install'); 

add_filter('comment_text', 'drawblog_add_image_to_comment');
add_action('comment_form', 'drawblog_comment_form');
add_action('comment_post', 'drawblog_save_image');

function drawblog_install() {
	global $drawblog_db_version;
	add_option("drawblog_db_version", $drawblog_db_version);
	if (!is_dir(WP_CONTENT_DIR . '/drawblog/images')){
		wp_mkdir_p(WP_CONTENT_DIR . '/drawblog/images', 755);
	}
	if (!get_option("drawblog_canvas_title")) add_option("drawblog_canvas_title", __('Click here to draw a picture to include in your comment.'));
	if (!get_option("drawblog_canvas_width")) add_option("drawblog_canvas_width", 400);
	if (!get_option("drawblog_canvas_height")) add_option("drawblog_canvas_height", 300);
	if (!get_option("drawblog_post_classname")) add_option("drawblog_post_classname", drawblog_determine_classname());
}

function drawblog_add_image_to_comment($comment_text){
	global $comment; 
	$drawblog_image = drawblog_get_image($comment->comment_ID);
	if (($drawblog_image) && 
		(is_file( WP_CONTENT_DIR . '/drawblog/images/' . $drawblog_image)) && 
		(getimagesize(  WP_CONTENT_DIR . '/drawblog/images/' . $drawblog_image) !== false)){			
			$comment_text = "<img src=\"". content_url(). '/drawblog/images/'.$drawblog_image."\" class=\"drawblogimage\"><br>".$comment_text;
	}
	return $comment_text;
}
function drawblog_get_image($comment_id){
	global $wpdb;
	$meta = get_comment_meta($comment_id, 'drawblog_image');
	return $meta[0];
}
function drawblog_comment_form(){
	global $drawblog_form_complete;
	if (!$drawblog_form_complete){
		echo drawblog_add_canvas();
		$drawblog_form_complete = true;
	}
}
function drawblog_save_image($comment_id){
	global $wpdb;
	if ($_POST['drawblog_include_pic'] == true){
		$data = $_POST['drawblog_picture'];
		$raw_data = str_replace(' ','+',$data);
		$filtered_data=substr($raw_data, strpos($raw_data, ",")+1);
		$data = base64_decode($filtered_data);
		$new_image = uniqid($comment_id.'_').'.png';
		$fp = fopen(WP_CONTENT_DIR . '/drawblog/images/'.$new_image, 'wb' );
		fwrite( $fp, $data);
		fclose( $fp );
		if (is_file(WP_PLUGIN_DIR . "/drawblog/icons/dbwm.png")){
			$im = imagecreatefrompng(WP_CONTENT_DIR . '/drawblog/images/'.$new_image);
			$src = imagecreatefrompng(WP_PLUGIN_DIR . "/drawblog/icons/dbwm.png");
			list($wm_width, $wm_height) = getimagesize(WP_PLUGIN_DIR . "/drawblog/icons/dbwm.png");
			imagecopy($im, $src, get_option('drawblog_canvas_width')-$wm_width, get_option('drawblog_canvas_height') - $wm_height, 0, 0, $wm_width, $wm_height);
			imagepng($im, WP_CONTENT_DIR . '/drawblog/images/'.$new_image);
		} 
		add_comment_meta($comment_id, 'drawblog_image', $new_image);
	}
}
function drawblog_add_canvas(){
	if (get_option('drawblog_api_key')!=''){
		$ch = curl_init('http://drawblog.com/auth.php');
		curl_setopt($ch, CURLOPT_POST, true);
		$postfields = 'apikey='.get_option('drawblog_api_key').'&domain='.$_SERVER['HTTP_HOST'];
		$postfields .='&theme='.get_stylesheet(); // if you're using the api, I need your theme
		curl_setopt($ch, CURLOPT_POSTFIELDS, $postfields);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		echo curl_exec($ch);
		curl_close($ch);
	}
	$width = get_option('drawblog_canvas_width');
	$height = get_option('drawblog_canvas_height');
	include "drawblog_canvas.php";
}

function drawblog_determine_classname(){
	$themedir = get_stylesheet_directory();
	$theme = get_stylesheet(); // I wish this function was called get_theme(), but whatever
	switch ($theme){		
		case 'custom-community':
			$postclass = 'post-content';
			break;
		case 'inferno-mf':
			$postclass = 'post';
			break;
		case 'easel':
		case 'eclipse':
		case 'ifeature':
			$postclass = 'entry';
			break;
		case 'responsive':
			$postclass = "post-entry";
			break;
		case 'mantra':
		case 'pagelines':
		case 'pinboard':
		case 'twentyeleven':
		case 'twentyten':
		case 'twentytwelve':
		default:
			$postclass = "entry-content";
			break;
	}
	return $postclass;
}

function get_image_data($img){	
	$domain_bits = parse_url($img);
	$domain = $domain_bits['host'];
	$filename = $domain_bits['path'];
	if ($domain == $_SERVER['SERVER_NAME']) {		
		$file = $img;
	} else {
		$file = plugins_url().'/drawblog/drawblog_safeimage.php?img='.urlencode($img);
	}
	$img_info = getimagesize($img);
	if ($img_info !== false){
		echo json_encode(array($file,$img_info[0], $img_info[1]));
	} else echo '';
}

if ( is_admin() ){
	add_action('admin_menu', 'drawblog_admin_menu');
	
	function drawblog_admin_menu() {
		add_options_page('DrawBlog', 'DrawBlog', 'administrator', 'drawblog', 'drawblog_settings_page');
	}
	function drawblog_update_options($values){
		$title = $values['drawblog_canvas_title'];		
		$width = intval($values['drawblog_canvas_width']);
		$height = intval($values['drawblog_canvas_height']);
		if ($width<=0) return __('Canvas width'); //returns other than 'success', below, indicate a field with an error. Canvases cannot be negative or zero values.
		if ($height<=0) return __('Canvas height');
		update_option('drawblog_api_key', $values['drawblog_api_key']);
		update_option('drawblog_canvas_width', $width);		
		update_option('drawblog_canvas_height', $height);
		update_option('drawblog_canvas_title', $title);				
		update_option('drawblog_post_classname', $values['post_class_name']);
		return 'success';
	}
	function drawblog_settings_page() {
		include "drawblog_admin.php";
	}
}
?>